package game;

import java.util.concurrent.CountDownLatch;
import java.util.concurrent.TimeUnit;

/**
 * This GameBoard class contains the current guess by the user.
 * All operations on this object should take place within code
 * blocks that are synchronized on the object.
 */
public class GameBoard {
  private int theGuess = 1;
  
  private CountDownLatch latch = new CountDownLatch(0);
  
  public void setGuess(int v) {
    theGuess = v;
  }
  
  public int getGuess() {
    return theGuess;
  }
  /**
   * Create a new CountDownLatch with the given count.
   * @param r the number of decrements before the latch releases
   */
  public void setLatch(int r) {
    latch = new CountDownLatch(r);
  }
  /**
   * Wait for the latch to be released through the actions of other threads
   * or through the passage of time.
   * @param millis number of milliseconds to wait before proceeding
   * @throws InterruptedException
   */
  public void awaitLatch(int millis) throws InterruptedException {
    latch.await(millis,TimeUnit.MILLISECONDS);
  }
  /**
   * Decrement the value of the latch.  Each of the players calls this method
   * to indicate that it has reviewed the latest guess.  When the count reaches
   * 0 the dealer will ask the user for another guess.
   */
  public void decrementLatch() {
    latch.countDown();
  }
}
